@@ -16,10 +16,10 @@ from je_editor.ui.ui_event.open_file.open_file_to_read.open_file_to_read import
 from je_editor.ui.ui_event.open_file.open_last_edit_file.open_last_edit_file import open_last_edit_file
 from je_editor.ui.ui_event.save_file.save_file_to_open.save_file_to_open import save_file_to_open
 from je_editor.ui.ui_event.save_file.save_file_to_open.save_file_to_open import save_file_then_can_run
-from je_editor.utils.code_tag.tag_keyword import HighlightText
+from je_editor.ui.ui_event.tag_keyword.tag_keyword import HighlightText
 from je_editor.utils.editor_content.content_save import open_content_and_start
-from je_editor.utils.text_process.program_exec.exec_text import ExecManager
-from je_editor.utils.text_process.program_exec.process_error import process_error_text
+from je_editor.ui.ui_event.text_process.program_exec.exec_text import ExecManager
+from je_editor.ui.ui_event.text_process.program_exec.process_error import process_error_text
 from je_editor.ui.ui_utils.font.font import get_font
 from je_editor.ui.ui_event.change_font.change_font import change_font
 from je_editor.ui.ui_event.change_font.change_font import change_font_size
@@ -95,8 +95,8 @@ class EditorMain(object):
         self.main_window.title("je_editor")
         self.code_edit_frame = ttk.Frame(self.main_window, padding="3 3 12 12")
         self.code_edit_frame.grid(column=0, row=0, sticky=(N, W, E, S))
-        self.run_result_frame = ttk.Frame(self.main_window, padding="3 3 12 12")
-        self.run_result_frame.grid(column=0, row=1, sticky=(N, W, E, S))
+        self.program_run_result_frame = ttk.Frame(self.main_window, padding="3 3 12 12")
+        self.program_run_result_frame.grid(column=0, row=1, sticky=(N, W, E, S))
         # Text start and end position
         self.start_position = "1.0"
         self.end_position = "end-1c"
@@ -109,14 +109,14 @@ class EditorMain(object):
         self.code_editor["yscrollcommand"] = self.code_editor_scrollbar_y.set
         self.code_editor_scrollbar_y.grid(column=1, row=0, sticky="ns")
         # run result
-        self.run_result = Text(self.run_result_frame)
-        self.run_result.grid(column=0, row=1, sticky=(N, W, E, S))
-        self.run_result.configure(state="disabled")
-        self.run_result.bind("<1>", lambda event: self.run_result.focus_set())
-        self.run_result_scrollbar_y = ttk.Scrollbar(self.run_result_frame, orient="vertical",
-                                                    command=self.run_result.yview)
-        self.run_result["yscrollcommand"] = self.run_result_scrollbar_y.set
-        self.run_result_scrollbar_y.grid(column=1, row=1, sticky="ns")
+        self.program_run_result_textarea = Text(self.program_run_result_frame)
+        self.program_run_result_textarea.grid(column=0, row=1, sticky=(N, W, E, S))
+        self.program_run_result_textarea.configure(state="disabled")
+        self.program_run_result_textarea.bind("<1>", lambda event: self.program_run_result_textarea.focus_set())
+        self.program_run_result_textarea_scrollbar_y = ttk.Scrollbar(self.program_run_result_frame, orient="vertical",
+                                                                     command=self.program_run_result_textarea.yview)
+        self.program_run_result_textarea["yscrollcommand"] = self.program_run_result_textarea_scrollbar_y.set
+        self.program_run_result_textarea_scrollbar_y.grid(column=1, row=1, sticky="ns")
         # Menubar
         # Main menu
         self.menu = tkinter.Menu(self.main_window)
@@ -130,7 +130,7 @@ class EditorMain(object):
         )
         self.menu.add_command(
             label="Run on shell",
-            command=lambda: execute_shell_command(self.run_result, self.code_editor)
+            command=lambda: execute_shell_command(self.program_run_result_textarea, self.code_editor)
         )
         self.menu.add_command(
             label="Stop",
@@ -145,12 +145,12 @@ class EditorMain(object):
             self.text_font_sub_menu.add_command(
                 label=str(self.font_tuple[i]),
                 command=lambda choose_font=self.font_tuple[i]:
-                change_font(self.code_editor, self.run_result, choose_font)
+                change_font(self.code_editor, self.program_run_result_textarea, choose_font)
             )
         for i in range(12, 36, 2):
             self.text_size_sub_menu.add_command(
                 label=str(i),
-                command=lambda font_size=i: change_font_size(self.code_editor, self.run_result, font_size)
+                command=lambda font_size=i: change_font_size(self.code_editor, self.program_run_result_textarea, font_size)
             )
         self.text_menu.add_cascade(label="Font", menu=self.text_font_sub_menu)
         self.text_menu.add_cascade(label="Font Size", menu=self.text_size_sub_menu)
@@ -182,7 +182,7 @@ class EditorMain(object):
         )
         self.popup_menu.add_command(
             label="Run on shell",
-            command=lambda: execute_shell_command(self.run_result, self.code_editor)
+            command=lambda: execute_shell_command(self.program_run_result_textarea, self.code_editor)
         )
         self.popup_menu.add_separator()
         self.popup_menu.add_cascade(label="File", menu=self.file_menu)
@@ -193,8 +193,8 @@ class EditorMain(object):
         # set resize
         self.code_edit_frame.columnconfigure(0, weight=1)
         self.code_edit_frame.rowconfigure(0, weight=1)
-        self.run_result_frame.columnconfigure(0, weight=1)
-        self.run_result_frame.rowconfigure(1, weight=1)
+        self.program_run_result_frame.columnconfigure(0, weight=1)
+        self.program_run_result_frame.rowconfigure(1, weight=1)
         self.main_window.columnconfigure(0, weight=1)
         self.main_window.rowconfigure(0, weight=1)
         # Highlight word
@@ -217,7 +217,7 @@ class EditorMain(object):
         )
         self.main_window.bind(
             "<Control-Key-F6>",
-            lambda bind_exec_shell_command: execute_shell_command(self.run_result, self.code_editor)
+            lambda bind_exec_shell_command: execute_shell_command(self.program_run_result_textarea, self.code_editor)
         )
         # is this test run?
         self.test_run = False
@@ -226,7 +226,7 @@ class EditorMain(object):
         if self.current_file is not None:
             self.auto_save = start_auto_save(self.auto_save, self.current_file, self.code_editor)
         self.exec_manager = ExecManager(
-            run_result=self.run_result,
+            program_run_result_textarea=self.program_run_result_textarea,
             process_error_function=process_error_text,
             main_window=self.main_window,
             running_menu=self.menu
